16.29. cdist-type__consul_watch_keyprefix(7) — cdist 4.10.11 documentation

# 16.29. cdist-type__consul_watch_keyprefix(7)

## 16.29.1. NAME

cdist-type__consul_watch_keyprefix - Manages consul keyprefix watches

## 16.29.2. DESCRIPTION

Generate and deploy watch definitions of type 'keyprefix' for a consul agent. See http://www.consul.io/docs/agent/watches.html for parameter documentation.

## 16.29.3. REQUIRED PARAMETERS

handler
  the handler to invoke when the data view updates
prefix
  the prefix of keys to watch for changes

## 16.29.4. OPTIONAL PARAMETERS

datacenter
  can be provided to override the agent's default datacenter
state
  if this watch is 'present' or 'absent'. Defaults to 'present'.
token
  can be provided to override the agent's default ACL token

## 16.29.5. EXAMPLES

    __consul_watch_keyprefix some-id \
       --prefix foo/ \
       --handler /usr/bin/my-prefix-handler.sh

## 16.29.6. SEE ALSO

cdist-type__consul_agent(7)

consul documentation at: <http://www.consul.io/docs/agent/watches.html>.

## 16.29.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.29.8. COPYING

Copyright (C) 2015 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.